#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_NBTRUE_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_NBTRUE_HPP_INCLUDED

#include <boost/simd/reduction/include/functions/nbtrue.hpp>

#endif
